This is a small plugin for pygame, which provides
some tools to make creating games with pygame easier.
The package is still incomplete as just one module, the `screenmanager`
which makes it easier to create scenes in pygame.

 - [complete documentation](https://github.com/Jefferson5286/PygTools.git)
## dependencies
 * python 3
 * pygame 2.0.0 ou superior
 
## installation

at a command prompt type

````commandline
pip install pygtools
````

## resources

>OBS: initially PygTools only has one module, but tools will be added over
> time

 * creating multiple screens for pygame
 * screen manager with minimal syntax based on kivy screen manager
